@@ -14,7 +14,9 @@
 #=======================================================================
 package PDF::API2::Basic::PDF::File;
 
-our $VERSION = '2.028'; # VERSION
+use strict;
+
+our $VERSION = '2.031'; # VERSION
 
 =head1 NAME
 
@@ -82,7 +84,7 @@ have been made to the memory representation.
 
 =item maxobj (R)
 
-Contains the first useable object number above any that have already appeared
+Contains the first usable object number above any that have already appeared
 in the file so far.
 
 =item outlist (P)
@@ -138,9 +140,6 @@ is in PDF which contains the location of the previous cross-reference table.
 
 =cut
 
-use strict;
-no strict "refs";
-
 use Scalar::Util qw(blessed);
 
 use vars qw($cr $irreg_char $reg_char $ws_char $delim_char %types);
@@ -158,6 +157,7 @@ $cr = '\s*(?:\015|\012|(?:\015\012))';
 
 my $readDebug = 0;
 
+use Carp;
 use IO::File;
 
 # Now for the basic PDF types
@@ -227,7 +227,7 @@ sub open {
     }
     else {
         die "File '$filename' does not exist !" unless -f $filename;
-        $fh = IO::File->new(($update ? '+' : '') . "<$filename") || return undef;
+        $fh = IO::File->new(($update ? '+' : '') . "<$filename") || return;
         $self->{' INFILE'} = $fh;
         if ($update) {
             $self->{' update'} = 1;
@@ -324,7 +324,7 @@ Appends the objects for output to the read file and then appends the appropriate
 
 sub append_file {
     my $self = shift();
-    return undef unless $self->{' update'};
+    return unless $self->{' update'};
 
     my $fh = $self->{' INFILE'};
 
@@ -456,7 +456,7 @@ sub readval {
     my ($result, $value);
 
     my $update = defined($opts{update}) ? $opts{update} : 1;
-    $str = update($fh, $str);
+    $str = update($fh, $str) if $update;
 
     $str =~ s/^$ws_char+//;               # Ignore initial white space
     $str =~ s/^\%[^\015\012]*$ws_char+//; # Ignore comments
@@ -475,13 +475,13 @@ sub readval {
                 my $key = PDF::API2::Basic::PDF::Name::name_to_string($1, $self);
                 ($value, $str) = $self->readval($str, %opts);
                 $result->{$key} = $value;
-            } 
-            elsif ($str =~ s|^/$ws_char+||) { 
+            }
+            elsif ($str =~ s|^/$ws_char+||) {
                 # fixes a broken key problem of acrobat. -- fredo
                 ($value, $str) = $self->readval($str, %opts);
                 $result->{'null'} = $value;
-            } 
-            elsif ($str =~ s|^//|/|) { 
+            }
+            elsif ($str =~ s|^//|/|) {
                 # fixes again a broken key problem of illustrator/enfocus. -- fredo
                 ($value, $str) = $self->readval($str, %opts);
                 $result->{'null'} = $value;
@@ -512,7 +512,7 @@ sub readval {
                 $value .= substr($str, 0, $length);
                 $result->{' stream'} = $value;
                 $result->{' nofilt'} = 1;
-                $str = update($fh, $str, 1) if $update;  # tell update we are in-stream and only need an endstream 
+                $str = update($fh, $str, 1) if $update;  # tell update we are in-stream and only need an endstream
                 $str = substr($str, index($str, 'endstream') + 9);
             }
         }
@@ -539,7 +539,7 @@ sub readval {
         $result->{' realised'} = 0;
         # gdj: FIXME: if any of the ws chars were crs, then the whole
         # string might not have been read.
-    } 
+    }
 
     # Object
     elsif ($str =~ m/^([0-9]+)$ws_char+([0-9]+)$ws_char+obj/s) {
@@ -547,7 +547,7 @@ sub readval {
         my $num = $1;
         $value = $2;
         $str =~ s/^([0-9]+)$ws_char+([0-9]+)$ws_char+obj//s;
-        ($obj, $str) = $self->readval($str, %opts, 'objnum' => $num, 'objgen' => $value);
+        ($obj, $str) = $self->readval($str, %opts);
         if ($result = $self->test_obj($num, $value)) {
             $result->merge($obj);
         }
@@ -565,7 +565,7 @@ sub readval {
         $value = $1;
         $str =~ s|^/($reg_char*)||s;
         $result = PDF::API2::Basic::PDF::Name->from_pdf($value, $self);
-    } 
+    }
 
     # Literal String
     elsif ($str =~ m/^\(/) {
@@ -619,7 +619,7 @@ sub readval {
         }
 
         $result = PDF::API2::Basic::PDF::String->from_pdf($value);
-    } 
+    }
 
     # Hex String
     elsif ($str =~ m/^</) {
@@ -627,7 +627,7 @@ sub readval {
         $fh->read($str, 255, length($str)) while (0 > index($str, '>'));
         ($value, $str) = ($str =~ /^(.*?)>(.*)/s);
         $result = PDF::API2::Basic::PDF::String->from_pdf('<' . $value . '>');
-    } 
+    }
 
     # Array
     elsif ($str =~ m/^\[/) {
@@ -643,27 +643,27 @@ sub readval {
             $str = update($fh, $str) if $update;   # str might just be exhausted!
         }
         $str =~ s/^\]//;
-    } 
+    }
 
     # Boolean
-    elsif ($str =~ m/^(true|false)$irreg_char/) {
+    elsif ($str =~ m/^(true|false)($irreg_char|$)/) {
         $value = $1;
         $str =~ s/^(?:true|false)//;
         $result = PDF::API2::Basic::PDF::Bool->from_pdf($value);
-    } 
+    }
 
     # Number
-    elsif ($str =~ m/^([+-.0-9]+)$irreg_char/) {
+    elsif ($str =~ m/^([+-.0-9]+)($irreg_char|$)/) {
         $value = $1;
         $str =~ s/^([+-.0-9]+)//;
         $result = PDF::API2::Basic::PDF::Number->from_pdf($value);
-    } 
+    }
 
     # Null
-    elsif ($str =~ m/^null$irreg_char/) {
+    elsif ($str =~ m/^null($irreg_char|$)/) {
         $str =~ s/^null//;
         $result = PDF::API2::Basic::PDF::Null->new;
-    } 
+    }
 
     else {
         die "Can't parse `$str' near " . ($fh->tell()) . " length " . length($str) . ".";
@@ -684,7 +684,7 @@ the read in object.
 sub read_obj {
     my ($self, $objind, %opts) = @_;
 
-    my $res = $self->read_objnum($objind->{' objnum'}, $objind->{' objgen'}, %opts) || return undef;
+    my $res = $self->read_objnum($objind->{' objnum'}, $objind->{' objgen'}, %opts) || return;
     $objind->merge($res) unless $objind eq $res;
     return $objind;
 }
@@ -698,43 +698,76 @@ Returns a fully read object of given number and generation in this file
 
 sub read_objnum {
     my ($self, $num, $gen, %opts) = @_;
+    croak 'Undefined object number in call to read_objnum($num, $gen)' unless defined $num;
+    croak 'Undefined object generation in call to read_objnum($num, $gen)' unless defined $gen;
+    croak "Invalid object number '$num' in call to read_objnum" unless $num =~ /^[0-9]+$/;
+    croak "Invalid object generation '$gen' in call to read_objnum" unless $gen =~ /^[0-9]+$/;
 
-    my $object_location = $self->locate_obj($num, $gen) || return undef;
+    my $object_location = $self->locate_obj($num, $gen) || return;
     my $object;
 
-    if (ref $object_location)
-    {
-        # Compressed object.
-        my $src = $self->read_objnum($object_location->[0], 0, %opts);
-        die 'Cannot find the compressed object stream' unless $src;
+    # Compressed object
+    if (ref($object_location)) {
+        my ($object_stream_num, $object_stream_pos) = @{$object_location};
 
-        $src->read_stream(1) if $src->{' nofilt'};
+        my $object_stream = $self->read_objnum($object_stream_num, 0, %opts);
+        die 'Cannot find the compressed object stream' unless $object_stream;
 
-        my $map = substr($src->{' stream'}, 0, $src->{'First'}->val);
-        my $objects = substr($src->{' stream'}, $src->{'First'}->val);
-        my @mappings = split(/\s+/, $map);
-        my $count = scalar(@mappings);
+        $object_stream->read_stream() if $object_stream->{' nofilt'};
 
-        my $index = $object_location->[1] * 2;
+        # An object stream starts with pairs of integers containing object numbers and
+        # stream offsets relative to the First key
+        my $fh;
+        my $pairs;
+        unless ($object_stream->{' streamfile'}) {
+            $pairs = substr($object_stream->{' stream'}, 0, $object_stream->{'First'}->val);
+        }
+        else {
+            open $fh, '<', $object_stream->{' streamfile'};
+            read($fh, $pairs, $object_stream->{'First'}->val());
+        }
+        my @map = split /\s+/, $pairs;
 
-        if ($mappings[$index] != $num)
-        {
-            die "Objind $num does not exist at index $index";
+        # Find the offset of the object in the stream
+        my $index = $object_stream_pos * 2;
+        die "Objind $num does not exist at index $index" unless $map[$index] == $num;
+        my $start = $map[$index + 1];
+
+        # Unless this is the last object in the stream, its length is determined by the
+        # offset of the next object
+        my $last_object_in_stream = $map[-2];
+        my $length;
+        if ($last_object_in_stream == $num) {
+            if ($object_stream->{' stream'}) {
+                $length = length($object_stream->{' stream'}) - $object_stream->{'First'}->val() - $start;
+            }
+            else {
+                $length = (-s $object_stream->{' streamfile'}) - $object_stream->{'First'}->val() - $start;
+            }
+        }
+        else {
+            my $next_start = $map[$index + 3];
+            $length = $next_start - $start;
         }
 
-        my $start = $mappings[++$index];
-        $index += 2;
+        # Read the object from the stream
+        my $stream = "$num 0 obj ";
+        unless ($object_stream->{' streamfile'}) {
+            $stream .= substr($object_stream->{' stream'}, $object_stream->{'First'}->val() + $start, $length);
+        }
+        else {
+            seek($fh, $object_stream->{'First'}->val() + $start, 0);
+            read($fh, $stream, $length, length($stream));
+            close $fh;
+        }
 
-        my $length = $index > $count ? length($objects) : $mappings[$index];
-        my $stream = "$num 0 obj" . substr($objects, $start, $length);
-
-        ($object) = $self->readval($stream, %opts, objnum => $num, objgen => $gen, update => 0);
+        ($object) = $self->readval($stream, %opts, update => 0);
         return $object;
     }
 
     my $current_location = $self->{' INFILE'}->tell;
     $self->{' INFILE'}->seek($object_location, 0);
-    ($object) = $self->readval('', %opts, 'objnum' => $num, 'objgen' => $gen);
+    ($object) = $self->readval('', %opts);
     $self->{' INFILE'}->seek($current_location, 0);
     return $object;
 }
@@ -819,7 +852,7 @@ sub out_obj {
     # in the hash) (which is super-fast).
     unless (exists $self->{' outlist_cache'}{$obj}) {
         push @{$self->{' outlist'}}, $obj;
-        $self->{' outlist_cache'}{$obj}++;
+        $self->{' outlist_cache'}{$obj} = 1;
     }
     return $obj;
 }
@@ -986,7 +1019,7 @@ sub locate_obj {
 
             if ($ref->[1] == $gen) {
                 return $ref->[0] if $ref->[2] eq 'n';
-                return         # if $ref->[2] eq 'f';
+                return;        # if $ref->[2] eq 'f';
             }
         }
         $tdict = $tdict->{' prev'};
@@ -1095,7 +1128,7 @@ sub readxrtr {
     $fh->seek($xpos, 0);
     $fh->read($buf, 22);
     $buf = update($fh, $buf); # fix for broken JAWS xref calculation.
-    
+
     my $xlist = {};
 
     ## seams that some products calculate wrong prev entries (short)
@@ -1105,7 +1138,7 @@ sub readxrtr {
     #    $buf =~ s/^(\s+|\S+|.)//i;
     #    $buf=update($fh,$buf);
     #}
-    
+
     if ($buf =~ s/^xref$cr//i) {
         # Plain XRef tables.
         while ($buf =~ m/^$ws_char*([0-9]+)$ws_char+([0-9]+)$ws_char*$cr(.*?)$/s) {
@@ -1120,7 +1153,7 @@ sub readxrtr {
             $xdiff = length($buf);
 
             $fh->read($buf, 20 * $xnum - $xdiff + 15, $xdiff);
-            while ($xnum-- > 0 and $buf =~ s/^0*([0-9]*)$ws_char+0*([0-9]+)$ws_char+([nf])$cr//) { 
+            while ($xnum-- > 0 and $buf =~ s/^0*([0-9]*)$ws_char+0*([0-9]+)$ws_char+([nf])$cr//) {
                 $xlist->{$xmin} = [$1, $2, $3] unless exists $xlist->{$xmin};
                 $xmin++;
             }
@@ -1167,28 +1200,32 @@ sub readxrtr {
             $start = shift(@index);
             $last = $start + shift(@index) - 1;
 
-            for $xmin ($start...$last)
+            for my $i ($start...$last)
             {
+                # Replaced "for $xmin" because it creates a loop-specific local variable, and we
+                # need $xmin to be correct for maxobj below.
+                $xmin = $i;
+
                 my @cols;
-    
+
                 for my $w (@widths)
                 {
                     my $data;
                     $data = $self->_unpack_xref_stream($w, substr($stream, 0, $w, '')) if $w;
-    
+
                     push @cols, $data;
                 }
-    
+
                 $cols[0] = 1 unless defined $cols[0];
                 if ($cols[0] > 2) {
                     die "Invalid XRefStm entry type ($cols[0]) at $xref_obj $xref_gen obj";
                 }
-    
+
                 next if exists $xlist->{$xmin};
-    
+
                 my @objind = ($cols[1], defined($cols[2]) ? $cols[2] : ($xmin ? 0 : 65535));
                 push @objind, ($cols[0] == 0 ? 'f' : 'n') if $cols[0] < 2;
-    
+
                 $xlist->{$xmin} = \@objind;
             }
         }
@@ -1200,7 +1237,7 @@ sub readxrtr {
 
     $tdict->{' loc'} = $xpos;
     $tdict->{' xref'} = $xlist;
-    $self->{' maxobj'} = $xmin if $xmin > $self->{' maxobj'};
+    $self->{' maxobj'} = $xmin + 1 if $xmin + 1 > $self->{' maxobj'};
     $tdict->{' prev'} = $self->readxrtr($tdict->{'Prev'}->val)
         if (defined $tdict->{'Prev'} and $tdict->{'Prev'}->val != 0);
     delete $tdict->{' prev'} unless defined $tdict->{' prev'};
