@@ -1,16 +1,17 @@
 package PDF::API2::Resource::CIDFont;
 
-our $VERSION = '2.028'; # VERSION
-
 use base 'PDF::API2::Resource::BaseFont';
 
+use strict;
+no warnings qw[ deprecated recursion uninitialized ];
+
+our $VERSION = '2.031'; # VERSION
+
 use Encode qw(:all);
 
 use PDF::API2::Basic::PDF::Utils;
 use PDF::API2::Util;
 
-no warnings qw[ deprecated recursion uninitialized ];
-
 =head1 NAME
 
 PDF::API2::Resource::CIDFont - Base class for CID fonts
@@ -25,7 +26,7 @@ Returns a cid-font object. base class form all CID based fonts.
 
 =cut
 
-sub new 
+sub new
 {
     my ($class,$pdf,$name,@opts) = @_;
     my %opts=();
@@ -55,24 +56,6 @@ sub new
     return($self);
 }
 
-=item $font = PDF::API2::Resource::CIDFont->new_api $api, $name, %options
-
-Returns a cid-font object. This method is different from 'new' that
-it needs an PDF::API2-object rather than a Text::PDF::File-object.
-
-=cut
-
-sub new_api 
-{
-    my ($class,$api,@opts)=@_;
-
-    my $obj=$class->new($api->{pdf},@opts);
-    $self->{' api'}=$api;
-
-    $api->{pdf}->out_obj($api->{pages});
-    return($obj);
-}
-
 sub glyphByCId { return( $_[0]->data->{g2n}->[$_[1]] ); }
 
 sub uniByCId { return( $_[0]->data->{g2u}->[$_[1]] ); }
@@ -81,21 +64,21 @@ sub cidByUni { return( $_[0]->data->{u2g}->{$_[1]} ); }
 
 sub cidByEnc { return( $_[0]->data->{e2g}->[$_[1]] ); }
 
-sub wxByCId 
+sub wxByCId
 {
     my $self=shift @_;
     my $g=shift @_;
     my $w;
 
-    if(ref($self->data->{wx}) eq 'ARRAY' && defined $self->data->{wx}->[$g]) 
+    if(ref($self->data->{wx}) eq 'ARRAY' && defined $self->data->{wx}->[$g])
     {
         $w = int($self->data->{wx}->[$g]);
-    } 
-    elsif(ref($self->data->{wx}) eq 'HASH' && defined $self->data->{wx}->{$g}) 
+    }
+    elsif(ref($self->data->{wx}) eq 'HASH' && defined $self->data->{wx}->{$g})
     {
         $w = int($self->data->{wx}->{$g});
-    } 
-    else 
+    }
+    else
     {
         $w = $self->missingwidth;
     }
@@ -106,18 +89,18 @@ sub wxByCId
 sub wxByUni { return( $_[0]->wxByCId($_[0]->data->{u2g}->{$_[1]}) ); }
 sub wxByEnc { return( $_[0]->wxByCId($_[0]->data->{e2g}->[$_[1]]) ); }
 
-sub width 
+sub width
 {
     my ($self,$text)=@_;
     return($self->width_cid($self->cidsByStr($text)));
 }
 
-sub width_cid 
+sub width_cid
 {
     my ($self,$text)=@_;
     my $width=0;
     my $lastglyph=0;
-    foreach my $n (unpack('n*',$text)) 
+    foreach my $n (unpack('n*',$text))
     {
         $width+=$self->wxByCId($n);
         if($self->{-dokern} && $self->haveKernPairs())
@@ -127,7 +110,7 @@ sub width_cid
                 $width-=$self->kernPairCid($lastglyph, $n);
             }
         }
-        $lastglyph=$n;                    
+        $lastglyph=$n;
     }
     $width/=1000;
     return($width);
@@ -139,7 +122,7 @@ Returns the cid-string from string based on the fonts encoding map.
 
 =cut
 
-sub _cidsByStr 
+sub _cidsByStr
 {
     my ($self,$s)=@_;
     $s=pack('n*',map { $self->cidByEnc($_) } unpack('C*',$s));
@@ -149,24 +132,24 @@ sub _cidsByStr
 sub cidsByStr
 {
     my ($self,$text)=@_;
-    if(is_utf8($text) && defined $self->data->{decode} && $self->data->{decode} ne 'ident') 
+    if(is_utf8($text) && defined $self->data->{decode} && $self->data->{decode} ne 'ident')
     {
         $text=encode($self->data->{decode},$text);
     }
-    elsif(is_utf8($text) && $self->data->{decode} eq 'ident') 
+    elsif(is_utf8($text) && $self->data->{decode} eq 'ident')
     {
         $text=$self->cidsByUtf($text);
-    } 
-    elsif(!is_utf8($text) && defined $self->data->{encode} && $self->data->{decode} eq 'ident') 
+    }
+    elsif(!is_utf8($text) && defined $self->data->{encode} && $self->data->{decode} eq 'ident')
     {
         $text=$self->cidsByUtf(decode($self->data->{encode},$text));
-    } 
-    elsif(!is_utf8($text) && $self->can('issymbol') && $self->issymbol && $self->data->{decode} eq 'ident') 
+    }
+    elsif(!is_utf8($text) && $self->can('issymbol') && $self->issymbol && $self->data->{decode} eq 'ident')
     {
         $text=pack('U*',(map { $_+0xf000 } unpack('C*',$text)));
         $text=$self->cidsByUtf($text);
     }
-    else 
+    else
     {
         $text=$self->_cidsByStr($text);
     }
@@ -186,20 +169,20 @@ sub cidsByUtf {
     return($s);
 }
 
-sub textByStr 
+sub textByStr
 {
     my ($self,$text)=@_;
     return($self->text_cid($self->cidsByStr($text)));
 }
 
-sub textByStrKern 
+sub textByStrKern
 {
     my ($self,$text,$size,$ident)=@_;
     return($self->text_cid_kern($self->cidsByStr($text),$size,$ident));
 }
 
-sub text 
-{ 
+sub text
+{
     my ($self,$text,$size,$ident)=@_;
     my $newtext=$self->textByStr($text);
     if(defined $size && $self->{-dokern})
@@ -216,7 +199,7 @@ sub text
         else
         {
 	        return("$newtext Tj");
-        }        
+        }
     }
     else
     {
@@ -224,12 +207,12 @@ sub text
     }
 }
 
-sub text_cid 
+sub text_cid
 {
     my ($self,$text,$size)=@_;
     if($self->can('fontfile'))
     {
-        foreach my $g (unpack('n*',$text)) 
+        foreach my $g (unpack('n*',$text))
         {
             $self->fontfile->subsetByCId($g);
         }
@@ -245,12 +228,12 @@ sub text_cid
     }
 }
 
-sub text_cid_kern 
+sub text_cid_kern
 {
     my ($self,$text,$size,$ident)=@_;
     if($self->can('fontfile'))
     {
-        foreach my $g (unpack('n*',$text)) 
+        foreach my $g (unpack('n*',$text))
         {
             $self->fontfile->subsetByCId($g);
         }
@@ -260,7 +243,7 @@ sub text_cid_kern
         my $newtext=' ';
         my $lastglyph=0;
         my $tBefore=0;
-        foreach my $n (unpack('n*',$text)) 
+        foreach my $n (unpack('n*',$text))
         {
             if($self->kernPairCid($lastglyph, $n))
             {
@@ -303,17 +286,17 @@ sub text_cid_kern
     }
 }
 
-sub kernPairCid 
+sub kernPairCid
 {
     return(0);
 }
 
-sub haveKernPairs 
+sub haveKernPairs
 {
     return(0);
 }
 
-sub encodeByName 
+sub encodeByName
 {
     my ($self,$enc) = @_;
     return if($self->issymbol);
@@ -323,7 +306,7 @@ sub encodeByName
     $self->data->{e2g}=[ map { $self->data->{u2g}->{$_} || 0 } @{$self->data->{e2u}} ];
 
     $self->data->{u2e}={};
-    foreach my $n (reverse 0..255) 
+    foreach my $n (reverse 0..255)
     {
         $self->data->{u2e}->{$self->data->{e2u}->[$n]}=$n unless(defined $self->data->{u2e}->{$self->data->{e2u}->[$n]});
     }
@@ -331,27 +314,27 @@ sub encodeByName
     return($self);
 }
 
-sub subsetByCId 
+sub subsetByCId
 {
     return(1);
 }
 
-sub subvec 
+sub subvec
 {
     return(1);
 }
 
-sub glyphNum 
-{ 
+sub glyphNum
+{
     my $self=shift @_;
-    if(defined $self->data->{glyphs}) 
+    if(defined $self->data->{glyphs})
     {
-        return ( $self->data->{glyphs} ); 
+        return ( $self->data->{glyphs} );
     }
-    return ( scalar @{$self->data->{wx}} ); 
+    return ( scalar @{$self->data->{wx}} );
 }
 
-sub outobjdeep 
+sub outobjdeep
 {
     my ($self, $fh, $pdf, %opts) = @_;
 
