@@ -1,11 +1,11 @@
 package PDF::API2::Resource::Font::CoreFont::courierbold;
 
-our $VERSION = '2.028'; # VERSION
-
 use strict;
 use warnings;
 
-our $FONTDATA = {
+our $VERSION = '2.031'; # VERSION
+
+sub data { return {
     'fontname' => 'Courier-Bold',
     'type' => 'Type1',
     'apiname' => 'CoBo',
@@ -513,4 +513,6 @@ our $FONTDATA = {
         'fi' => '600',                           # U+0xFB01
         'fl' => '600',                           # U+0xFB02
     }, # HORIZ. WIDTH TABLE
-};
+} };
+
+1;
