@@ -1,8 +1,11 @@
 package PDF::API2::Resource::Font::CoreFont::helveticaoblique;
 
-our $VERSION = '2.023'; # VERSION
+use strict;
+use warnings;
 
-$FONTDATA = {
+our $VERSION = '2.031'; # VERSION
+
+sub data { return {
     'fontname' => 'Helvetica-Oblique',
     'type' => 'Type1',
     'apiname' => 'HeIt',
@@ -509,4 +512,6 @@ $FONTDATA = {
         'fi' => '500',                           # U+0xFB01
         'fl' => '500',                           # U+0xFB02
     }, # HORIZ. WIDTH TABLE
-};
+} };
+
+1;
