@@ -1,17 +1,18 @@
 package PDF::API2::Resource::Font::Postscript;
 
-our $VERSION = '2.028'; # VERSION
-
 use base 'PDF::API2::Resource::Font';
 
+use strict;
+no warnings qw[ deprecated recursion uninitialized ];
+
+our $VERSION = '2.031'; # VERSION
+
 use Encode qw(:all);
 use IO::File qw();
 
 use PDF::API2::Util;
 use PDF::API2::Basic::PDF::Utils;
 
-no warnings qw[ deprecated recursion uninitialized ];
-
 sub new {
     my ($class, $pdf, $psfile, %opts) = @_;
     my ($self,$encoding);
@@ -64,18 +65,6 @@ sub new {
 
     $self->{-nocomps}=1 if($opts{-nocomps});
     $self->{-dokern}=1 if($opts{-dokern});
-    
-    return($self);
-}
-
-sub new_api {
-    my ($class, $api, @para) = @_;
-
-    $class = ref $class if ref $class;
-    my $self = $class->new($api->{pdf},@para);
-
-    $self->{' apipdf'}=$api->{pdf};
-    $self->{' api'}=$api;
 
     return($self);
 }
@@ -86,43 +75,42 @@ sub readPFAPFB {
 
     die "cannot find font '$file' ..." unless(-f $file);
 
-    $l=-s $file;
+    my $l=-s $file;
 
-    open(INF,$file);
-    binmode(INF,':raw');
-    read(INF,$line,2);
+    open(my $inf, "<", $file) or die "$!: $file";
+    binmode($inf,':raw');
+    read($inf,$line,2);
     @lines=unpack('C*',$line);
     if(($lines[0]==0x80) && ($lines[1]==1)) {
-        read(INF,$line,4);
+        read($inf,$line,4);
         $l1=unpack('V',$line);
-        seek(INF,$l1,1);
-        read(INF,$line,2);
+        seek($inf,$l1,1);
+        read($inf,$line,2);
         @lines=unpack('C*',$line);
         if(($lines[0]==0x80) && ($lines[1]==2)) {
-            read(INF,$line,4);
+            read($inf,$line,4);
             $l2=unpack('V',$line);
         } else {
             die "corrupt pfb in file '$file' at marker='2'.";
         }
-        seek(INF,$l2,1);
-        read(INF,$line,2);
+        seek($inf,$l2,1);
+        read($inf,$line,2);
         @lines=unpack('C*',$line);
         if(($lines[0]==0x80) && ($lines[1]==1)) {
-            read(INF,$line,4);
+            read($inf,$line,4);
             $l3=unpack('V',$line);
         } else {
             die "corrupt pfb in file '$file' at marker='3'.";
         }
-        seek(INF,0,0);
-        @lines=<INF>;
-        close(INF);
+        seek($inf,0,0);
+        @lines=<$inf>;
         $stream=join('',@lines);
         $t1stream=substr($stream,6,$l1);
         $t1stream.=substr($stream,12+$l1,$l2);
         $t1stream.=substr($stream,18+$l1+$l2,$l3);
     } elsif($line eq '%!') {
-        seek(INF,0,0);
-        while($line=<INF>) {
+        seek($inf,0,0);
+        while($line=<$inf>) {
             if(!$l1) {
                 $head.=$line;
                 if($line=~/eexec$/){
@@ -147,6 +135,7 @@ sub readPFAPFB {
     } else {
         die "unsupported font-format in file '$file' at marker='1'.";
     }
+    close($inf);
 
     return($l1,$l2,$l3,$t1stream);
 }
@@ -154,7 +143,7 @@ sub readPFAPFB {
 
 # $datahashref = $self->readAFM( $afmfile );
 
-sub readAFM 
+sub readAFM
 {
     my ($self,$file)=@_;
     my $data={};
@@ -165,11 +154,11 @@ sub readAFM
     $data->{lastchar}=0;
 
     if(! -e $file) {die "file='$file' not existant.";}
-    open(AFMF, $file) or die "Can't find the AFM file for $file";
+    open(my $afmf, "<", $file) or die "Can't find the AFM file for $file";
     local($/, $_) = ("\n", undef);  # ensure correct $INPUT_RECORD_SEPARATOR
-    while ($_=<AFMF>) 
+    while ($_=<$afmf>)
     {
-        if (/^StartCharMetrics/ .. /^EndCharMetrics/) 
+        if (/^StartCharMetrics/ .. /^EndCharMetrics/)
         {
         # only lines that start with "C" or "CH" are parsed
             next unless $_=~/^CH?\s/;
@@ -196,12 +185,12 @@ sub readAFM
             $data->{kern}||={};
             if($_=~m|^KPX\s+(\S+)\s+(\S+)\s+(\S+)\s*$|i)
             {
-                $data->{kern}->{"$1:$2"}=$3;    
+                $data->{kern}->{"$1:$2"}=$3;
             }
         }
         elsif(/^StartComposites/ .. /^EndComposites/)
         {
-            $data->{comps}||={}; 
+            $data->{comps}||={};
             if($_=~m|^CC\s+(\S+)\s+(\S+)\s+;|i)
             {
                 my ($name,$comp)=($1,$2);
@@ -213,32 +202,32 @@ sub readAFM
                     my @c1=split(/\s+/,shift @cv);
                     push @{$rng},$c1[1],$c1[2],$c1[3];
                 }
-                $data->{comps}->{$name}=$rng;    
+                $data->{comps}->{$name}=$rng;
             }
         }
         last if $_=~/^EndFontMetrics/;
-        if (/(^\w+)\s+(.*)/) 
+        if (/(^\w+)\s+(.*)/)
         {
             my($key,$val) = ($1, $2);
             $key = lc $key;
-            if (defined $data->{$key}) 
+            if (defined $data->{$key})
             {
             #   $data->{$key} = [ $data->{$key} ] unless ref $data->{$key};
             #   push(@{$data->{$key}}, $val);
-            } 
-            else 
+            }
+            else
             {
                 $val=~s/[\x00\x1f]+//g;
                 $data->{$key} = $val;
             }
-        } 
-        else 
+        }
+        else
         {
                 ## print STDERR "Can't parse: $_";
         }
     }
-    close(AFMF);
-    unless (exists $data->{wx}->{'.notdef'}) 
+    close($afmf);
+    unless (exists $data->{wx}->{'.notdef'})
     {
         $data->{wx}->{'.notdef'} = 0;
         $data->{bbox}{'.notdef'} = [0, 0, 0, 0];
@@ -250,11 +239,11 @@ sub readAFM
     $data->{fontname}=~s/[\x00-\x20]+//og;
     ## $data->{fontname}=~s/[^A-Za-z0-9]+//og;
 
-    if(defined $data->{fullname}) 
+    if(defined $data->{fullname})
     {
         $data->{altname}=$data->{fullname};
-    } 
-    else 
+    }
+    else
     {
         $data->{altname}=$data->{familyname};
         $data->{altname}.=' Italic' if($data->{italicangle}<0);
@@ -274,17 +263,17 @@ sub readAFM
     $data->{issymbol} = 0;
     $data->{fontbbox} = [ split(/\s+/,$data->{fontbbox}) ];
 
-    $data->{apiname}=join('',map { $_=~s/[^A-Za-z0-9]+//og; $_=ucfirst(lc(substr($_,0,2))); $_; } split(/\s+/,$data->{apiname}));
+    $data->{apiname}=join('', map { ucfirst(lc(substr($_, 0, 2))) } split m/[^A-Za-z0-9\s]+/, $data->{apiname});
 
     $data->{flags} = 34;
 
     $data->{uni}||=[];
-    foreach my $n (0..255) 
+    foreach my $n (0..255)
     {
         $data->{uni}->[$n]=uniByName($data->{char}->[$n] || '.notdef') || 0;
     }
     delete $data->{bbox};
-    
+
     return($data);
 }
 
@@ -302,7 +291,7 @@ sub readPFM {
     $data->{char}=[];
 
     my $buf;
-    open($fh,$file) || return undef;
+    open($fh, "<", $file) || return;
     binmode($fh,':raw');
     read($fh,$buf,117 + 30);
 
@@ -436,8 +425,7 @@ sub readPFM {
 
     $data->{fontname}=$df{psName};
     $data->{fontname}=~s/[^A-Za-z0-9]+//og;
-    $data->{apiname}=$df{windowsName};
-    $data->{apiname}=join('',map { $_=~s/[^A-Za-z0-9]+//og; $_=ucfirst(lc(substr($_,0,2))); $_; } split(/\s+/,$data->{apiname}));
+    $data->{apiname}=join('', map { ucfirst(lc(substr($_, 0, 2))) } split m/[^A-Za-z0-9\s]+/, $df{windowsName});
 
     $data->{upem}=1000;
 
