@@ -1,14 +1,15 @@
 package PDF::API2::Resource::XObject::Image::GD;
 
-our $VERSION = '2.023'; # VERSION
-
 use base 'PDF::API2::Resource::XObject::Image';
 
+use strict;
+no warnings qw[ deprecated recursion uninitialized ];
+
+our $VERSION = '2.031'; # VERSION
+
 use PDF::API2::Util;
 use PDF::API2::Basic::PDF::Utils;
 
-no warnings qw[ deprecated recursion uninitialized ];
-
 sub new {
     my ($class,$pdf,$obj,$name,@opts) = @_;
     my $self;
@@ -25,20 +26,11 @@ sub new {
     return($self);
 }
 
-sub new_api {
-    my ($class,$api,@opts)=@_;
-
-    my $obj=$class->new($api->{pdf},@opts);
-    $obj->{' api'}=$api;
-
-    return($obj);
-}
-
 sub read_gd {
     my $self = shift @_;
     my $gd = shift @_;
     my %opts = @_;
-    
+
     my ($w,$h) = $gd->getBounds();
     my $c = $gd->colorsTotal();
 
